@@ -8,9 +8,9 @@ from .models import PayMode, Currency, Transact, SandBox
 
 
 class PayModeAdmin(admin.ModelAdmin):
-    fields = ('id', 'pay_mode',)
-    list_display = ('id', 'pay_mode',)
-    search_fields = ('id', 'pay_mode',)
+    fields = ('id', 'pay_mode', "pay_value")
+    list_display = ('id', 'pay_mode', "pay_value")
+    search_fields = ('id', 'pay_mode' "pay_value",)
     readonly_fields = ['id']
 
 
@@ -29,15 +29,15 @@ class SandBoxAdmin(admin.ModelAdmin):
 
 
 class TransactAdmin(admin.ModelAdmin):
-    fields = ('id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+    fields = ('id', 'account', 'their_account', 'transact_id', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
               'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
               'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
     list_display = (
-        'id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+        'id', 'account', 'their_account', 'transact_id', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
         'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
         'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
     search_fields = (
-        'id', 'account', 'their_account', 'transact_no', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
+        'id', 'account', 'their_account', 'transact_id', 'enroll_id', 'transact_time', 'platform_id', 'order_no',
         'opposite_account', 'summary', 'currency', 'income', 'outgo', 'balance', 'pay_mode', 'goods_info',
         'pay_info', 'remark', 'images', 'sand_box', 'is_reverse',)
     # list_filter = ['platform', 'currency', 'account', 'their_account', 'order_no']
