@@ -6,6 +6,7 @@ import time
 
 class PayMode(models.Model):
     pay_mode = models.CharField(verbose_name='支付方式 ', max_length=128)
+    pay_value = models.CharField(verbose_name='支付方式 ', max_length=128)
 
     # description = models.CharField(verbose_name='描述 ', max_length=128) # sieyoo准备加
 
@@ -90,7 +91,7 @@ class Transact(models.Model):
     create_transact_id = year_timestamp() + zero_code
 
     # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default=create_transact_id) # 应为transact号
-    transact_no = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
+    transact_id = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
     enroll_id = models.BigIntegerField(verbose_name='报名id', db_index=True, null=True, )  # 应为transact号
     # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default='') # 应为transact号
     transact_time = models.DateTimeField(verbose_name='交易时间', auto_now_add=True)
