@@ -168,17 +168,16 @@ class FinanceTransactService:
         #     return Response({'err': 4002, 'msg': 'token验证失败', })
 
         # ========== 二、必填性检查 ==========
-        if not param.get('platform', ''):
+        if not param.get('platform', '') and not param.get('platform_id', ''):
             return None, '缺少platform'
-        if not param.get('amount', ''):
+        if not param.get('amount', '') and not param.get('income', '') and not param.get('outgo', ''):
             return None, '缺少amount'
-        if not param.get('currency', ''):
+        if not param.get('currency', '') and not param.get('currency_id', ''):
             return None, '缺少currency'
-        if not param.get('pay_mode', ''):
+        if not param.get('pay_mode', '') and not param.get('pay_mode_id', ''):
             return None, '缺少pay_mode'
         if not param.get('summary', ''):
             return None, '缺少summary'
-
         # ========== 三、内容的类型准确性检查 ==========
         # 判断无transact_id为新建，否则为修改
         is_create = True
@@ -191,11 +190,14 @@ class FinanceTransactService:
             if not has_id:
                 return None, 'id不存在'
         # 判断平台是否存在
-        platform_name = param.get('platform', '')
-        platform_info, err = UserPlatformService.get_platform_info(platform_name=platform_name)
-        if err:
-            return None, '平台不存在: ' + platform_name
-        item['platform_id'] = platform_info.get('platform_id')
+        if not param.get('platform_id', ''):
+            platform_name = param.get('platform', '')
+            platform_info, err = UserPlatformService.get_platform_info(platform_name=platform_name)
+            if err:
+                return None, '平台不存在: ' + platform_name
+            item['platform_id'] = platform_info.get('platform_id')
+        else:
+            item['platform_id'] = param.get('platform_id', '')
         # 发起交易的账号ID，如果没有则默认自己
         account_id = int(param.get('account_id', ''))
         item['account'] = BaseInfo.objects.filter(id=account_id).first()
@@ -234,7 +236,7 @@ class FinanceTransactService:
         now_time = timezone.now().astimezone(tz=tz).strftime("%Y-%m-%d %H:%M:%S")
         now = datetime.strptime(now_time, '%Y-%m-%d %H:%M:%S')
         # 如果没有时间则生成交易时间
-        transact_time = param.get('transact_time', '')
+        transact_time = str(param.get('transact_time', ''))
         # if transact_time else timezone.localtime() if is_create TODO USE_TZ = False 时会报错 如果USE_TZ设置为True时，Django会使用系统默认设置的时区，即America/Chicago，此时的TIME_ZONE不管有没有设置都不起作用。
         item['transact_time'] = datetime.strptime(transact_time, '%Y-%m-%d %H:%M:%S') \
             if transact_time else now if is_create \
@@ -243,30 +245,48 @@ class FinanceTransactService:
             return None, '交易时间格式不正确'
 
         # 边界检查：币种是否存在
-        currency = param.get('currency', '')
-        item['currency_set'] = Currency.objects.filter(currency=currency).first()
-        if item['currency_set'] is None:
-            return None, 'currency不存在'
-        item['currency'] = item['currency_set'].id
+        if not param.get('currency_id', ''):
+            currency = param.get('currency', '')
+            item['currency_set'] = Currency.objects.filter(currency=currency).first()
+            if item['currency_set'] is None:
+                return None, 'currency不存在'
+            item['currency'] = item['currency_set'].id
+        else:
+            item['currency_set'] = Currency.objects.filter(id=param.get('currency_id', '')).first()
+            if item['currency_set'] is None:
+                return None, 'currency不存在'
+            item['currency'] = param.get('currency_id', '')
 
         # 判断支付方式，并根据支付方式判断是否要从内部余额中扣款
-        pay_mode = param.get('pay_mode', 'BALANCE')
-        # 边界检查：支付方式是否存在
-        item['pay_mode_set'] = PayMode.objects.filter(pay_mode=pay_mode).first()
-        if item['pay_mode_set'] is None:
-            return None, 'pay_mode不存在'
-        item['pay_mode'] = item['pay_mode_set'].id
+        if not param.get('pay_mode_id', ''):
+            pay_mode = param.get('pay_mode', '')
+            # 边界检查：支付方式是否存在
+            item['pay_mode_set'] = PayMode.objects.filter(pay_mode=pay_mode).first()
+            if item['pay_mode_set'] is None:
+                return None, 'pay_mode不存在'
+            item['pay_mode'] = item['pay_mode_set'].id
+        else:
+            item['pay_mode_set'] = PayMode.objects.filter(id=param.get('pay_mode_id', '')).first()
+            if item['pay_mode_set'] is None:
+                return None, 'pay_mode不存在'
+            item['pay_mode'] = param.get('pay_mode_id', '')
 
-        # 支出或收入 ----------------------------------------------------------------------
-        if not Jt.is_number(param.get('amount', '')):
-            return None, 'amount必须是数字'
-        amount = Decimal(param.get('amount', 0.0))  # todo 财务系统不存在四舍五入，一分都不多给
-        if amount == 0:
-            return None, '交易金额不能为0'
-        income = amount if amount > 0 else Decimal(0.0)
-        item['income'] = income
-        outgo = Decimal(math.fabs(amount)) if amount < 0 else Decimal(0.0)
-        item['outgo'] = outgo
+            # 支出或收入 ----------------------------------------------------------------------
+        if not param.get('income', '') and not param.get('outgo', ''):
+            if not Jt.is_number(param.get('amount', '')):
+                return None, 'amount必须是数字'
+            amount = Decimal(param.get('amount', 0.0))  # todo 财务系统不存在四舍五入，一分都不多给
+            if amount == 0:
+                return None, '交易金额不能为0'
+            income = amount if amount > 0 else Decimal(0.0)
+            item['income'] = income
+            outgo = Decimal(math.fabs(amount)) if amount < 0 else Decimal(0.0)
+            item['outgo'] = outgo
+        else:
+            income = param.get('income', '')
+            item['income'] = income
+            outgo = param.get('outgo', '')
+            item['outgo'] = outgo
 
         enroll_id = param.get('enroll_id', '')
         if enroll_id:
@@ -297,7 +317,7 @@ class FinanceTransactService:
         last_balance = balance_set['balance'] if balance_set is not None else Decimal(0.0)
 
         item['balance'] = last_balance
-        if pay_mode == "BALANCE":
+        if item['pay_mode_set'].pay_mode == "BALANCE":
             balance = last_balance + income - outgo
             item['balance'] = balance
 
@@ -334,6 +354,7 @@ class FinanceTransactService:
         # 在新建订单时：如果平台订单号重复，金额不能重复，收方和支出方不能重复，金额也不能重复。
         if is_create:
             repeat_order_set = Transact.objects.filter(
+                Q(sand_box_id=item['sand_box']) &
                 Q(order_no=order_no) &
                 Q(account_id=account_id) &
                 (Q(income=income) | Q(outgo=outgo))
