@@ -2,6 +2,7 @@ from decimal import Decimal
 import random
 
 import pytz
+from django.forms import model_to_dict
 from rest_framework import serializers
 
 from xj_enroll.utils.custom_tool import format_params_handle
@@ -207,3 +208,30 @@ class FinanceTransactsService:
             filter_filed_list=field_list
         )
         return transact_filter_dict, None
+
+    @staticmethod
+    def detail_all(order_no=None):
+        """
+        查询订单性情
+        """
+        if not order_no:
+            return None, None
+
+        transact_obj = Transact.objects
+
+        if order_no:
+            transact_filter_obj = transact_obj.filter(order_no=order_no).values("order_no", "transact_id", "account_id",
+                                                                                "enroll_id",
+                                                                                "their_account_id",
+                                                                                "platform_id",
+                                                                                "income", "outgo", "balance",
+                                                                                "currency_id", "pay_mode_id",
+                                                                                "summary")
+        else:
+            return None, "没有找到对应的数据"
+
+        if not transact_filter_obj:
+            return None, "没有找到对应的数据"
+
+        # print(model_to_list(transact_filter_obj))
+        return transact_filter_obj, None
